#include "dumpacct.h"

/*
 * dumpacct.c
 *
 * program that dumps the contents of an account
 */

void main(int argc, char *argv[])
{
  int amount, md_counter, d_counter;
  char *acctnum, *analnum, *acctnam;
  char minibuff[513];

  if (argc < 2) {
    fprintf(stderr, "You must supply an account number.\n");
    exit(0);
  }

  /* check validity of supplied account number and then copy it to 
   * the local buffers acctnum and analnum so that if no analytical
   * number is supplied, analnum carries the default value of "--"
   */
  if ((strlen(argv[1]) != 3) ||
      ((argc > 2) && (strlen(argv[2]) != 2))) {
    fprintf(stderr, "Invalid account number.\n");
    exit(0);
  }
  acctnum = malloc(4);
  analnum = malloc(3);
  acctnum = strcpy(acctnum, argv[1]);
  if (argc > 2)
    analnum = strcpy(analnum, argv[2]);
  else analnum = "--";

  initBackend(DATABASE);                /* initialize the backend connection */

  acctnam = malloc(61);
  if ((acctnam = acctQuery(acctnam, acctnum, analnum)) == NULL) {
    fprintf(stderr, "The account you specified is not in the chart of accounts.\n");
    exit_nicely();
  } else {
    printf("%s %s: %s\n", acctnum, analnum, acctnam);
  }

  md_counter = d_counter = 0;
  sprintf(minibuff, "DECLARE a1 CURSOR FOR SELECT W1.ent_date, W1.por_cislo, W2.desig, W1.md_amt, W1.d_amt FROM denik W1, descs W2 WHERE W1.ent_date=W2.ent_date AND W1.por_cislo=W2.por_cislo AND ((W1.md_acct='%s' AND W1.md_anal='%s') OR (W1.d_acct='%s' AND W1.d_anal='%s')) ORDER BY ent_date, por_cislo;", acctnum, analnum, acctnum, analnum);
  startTransaction();
  runQuery(minibuff);
  printf("=================================================================\n");
  while (fetchNext("a1")) {
    printf("%s %-30s ", getField("ent_date"), getField("desig"));
    if ((amount = atoi(getField("md_amt"))) > 0) {
      printf("%8d.%02d ", (amount/100), (amount%100));
      md_counter = md_counter + amount;
    } else printf("            ");
    if ((amount = atoi(getField("d_amt"))) > 0) {
      printf("%8d.%02d", (amount/100), (amount%100));
      d_counter = d_counter + amount;
    }
    printf("\n");
  }
  printf("\nTOTALS:                                   %8d.%02d %8d.%02d\n", (md_counter/100), (md_counter%100), (d_counter/100), (d_counter%100));

  endTransaction();
  
  exit_nicely();
}
      
